/**********************************************************************/
/* sid2ced.rexx - macro that allows Timm Martin's dirutil, 'SID', to  */
/*                properly pass filenames to CygnusEd Professional,   */
/*                for editing.                                        */
/*                                                                    */
/*  To enable SID to use this mechanism, edit your SID.config file,   */
/*  replacing the 'FileEdit' line with this one:                      */
/*                                                                    */
/*  FileEdit=c:run c:rx sid2ced.rexx                                  */
/*                                                                    */
/*  You'll have to either restart SID or load the new configuration   */
/*  in order for this new feature to be utilized. Once reconfigured,  */
/*  highlighting a text file and subsequently clicking on the 'EDIT'  */
/*  gadget will now allow you to edit files from within SID, using    */
/*  CygnusEd Professional.                                            */
/*                                                                    */
/*  sid2ced will first check to see if CED is already running and,    */
/*  if not, will attempt to invoke it. Once running (or already       */
/*  started), it asks CED if there is already a file open. If so,     */
/*  it opens a new window before loading the new file, so as not to   */
/*  lose the old one. Once loaded, CED is made active, moved to the   */
/*  front of the display, and sid2ced exits.                          */
/*--------------------------------------------------------------------*/
/*  This is a highly modified version of the code found in the files  */
/*  'u.rexx' (author unknown), and 'loadced.rexx' (copyrighted by     */
/*  Steve Gillmor, Richard Lee Stockton and Gramma Software). Their   */
/*  copyrights remain intact, and I've added my own.                  */
/*                                                                    */
/*  (c) 1989 Steve Gillmor, Richard Lee Stockton and Gramma Software. */
/*    This code is freely distributable as long as this copyright     */
/*   notice remains, unchanged, at the start of the code. Thank you.  */
/*                                                                    */
/*  (c) 1989 Michael Koch                                             */
/**********************************************************************/

OPTIONS RESULTS                 /* need to get 'status' from ced */

PARSE ARG filename                    /* store incoming filename */
IF filename == "" THEN EXIT 10         /* no filename? then quit */

path = PRAGMA('d')                   /* get full path to 'filename' */

IF FIND(SHOW('P'),'rexx_ced') == 0 THEN    /* if ced isn't up... */
   DO
      ADDRESS COMMAND 'run c:ced'               /* ... get it up */
      'waitforport rexx_ced' /* wait for port to appear (max=10 secs) */
      IF FIND(SHOW('P'),'rexx_ced') == 0 THEN     /* check again */
         EXIT 20               /* still not available? then quit */
      ELSE ADDRESS 'rexx_ced'   /* get in communication with ced */
   END
ELSE                    /* if ced is up, check for existing file */
   DO
      ADDRESS 'rexx_ced'                          /* talk to ced */
      status 17         /* ask ced how many lines in active file */
      IF RESULT>=1 THEN 'open new' /* if >0 lines, open new window */
   END

/* At this point, we've gotten CED up and running (hopefully), and we've */
/* prevented any previously-opened files from being lost. Now we're      */
/* ready to open the filename passed by SID. Due to the fact that CED    */
/* interprets the quotation marks as part of the filename, we've got to  */
/* strip those out first. We also want to make sure the full path to the */
/* file is correctly passed. If the path doesn't end with a colon, we'll */
/* have to add a slash before the filename.                              */

IF RIGHT(path,1) == ':' THEN
   'open' path||STRIP(TRANSLATE(filename,'','"'))
ELSE
   'open' path||'/'||STRIP(TRANSLATE(filename,'','"'))

'expand view'               /* Give our file the biggest possible window */
'cedtofront'        /* CED opens behind WB. Tell it to come to the front */

EXIT 0
